==> phpsysinfo_2.5.1.orig.tar.gz: phpsysinfo/includes/lang/sk.php <==
<?php
//
// phpSysInfo - A PHP System Information Script
// http://phpsysinfo.sourceforge.net/
//
// This program is free software; you can redistribute it and/or
// modify it under the terms of the GNU General Public License
// as published by the Free Software Foundation; either version 2
// of the License, or (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
//
// $Id: sk.php,v 1.12 2005/12/07 15:02:11 bigmichi1 Exp $

$charset                = 'iso-8859-2';

$text['title']          = 'Informcie o systme';

$text['vitals']         = 'Zkladn informcie';
$text['hostname']       = 'Meno potaa';
$text['ip']             = 'IP adresa';
$text['kversion']       = 'Verzia jadra';
$text['dversion']       = 'Distro Name';
$text['uptime']         = 'Uptime';
$text['users']          = 'Prihlsench uvateov';
$text['loadavg']        = 'Priemer loadu';

$text['hardware']       = 'Hardwarov informcie';
$text['numcpu']         = 'Procesory';
$text['cpumodel']       = 'Model';
$text['cpuspeed']       = 'Frekvencia';
$text['busspeed']       = 'BUS Speed';
$text['cache']          = 'Vekos cache';
$text['bogomips']       = 'Bogomipsov';

$text['pci']            = 'PCI zariadenia';
$text['ide']            = 'IDE zariadenia';
$text['scsi']           = 'SCSI zariadenia';
$text['usb']            = 'USB zariadenia';

$text['netusage']       = 'Pouvanie siete';
$text['device']         = 'Zariadenia';
$text['received']       = 'Prijatch';
$text['sent']           = 'Odoslanch';
$text['errors']         = 'Chyby/Vypustench';

$text['memusage']       = 'Obsadenie pamti';
$text['phymem']         = 'Fyzick pam';
$text['swap']           = 'Swap';

$text['fs']             = 'Namountovan sborov systmy';
$text['mount']          = 'Adresr';
$text['partition']      = 'Partcia';

$text['percent']        = 'Obsadench';
$text['type']           = 'Typ';
$text['free']           = 'Vonch';
$text['used']           = 'Pouitch';
$text['size']           = 'Vekos';
$text['totals']         = 'Celkom';

$text['kb']             = 'KB';
$text['mb']             = 'MB';
$text['gb']             = 'GB';

$text['none']           = 'iadne';

$text['capacity']       = 'Kapacita';

$text['template']       = 'ablna';
$text['language']       = 'Jazyk';
$text['submit']         = 'Odosla';
$text['created']        = 'Vytvoren pomocou';
$text['locale']         = 'en_US';
$text['gen_time']       = 'on %b %d, %Y at %I:%M %p';

$text['days']           = 'dn';
$text['hours']          = 'hodn';
$text['minutes']        = 'mint';
  
$text['temperature']    = 'Temperature';
$text['voltage']        = 'Voltage';
$text['fans']           = 'Fans';
$text['s_value']        = 'Value';
$text['s_min']          = 'Min';
$text['s_max']          = 'Max';
$text['s_div']          = 'Div';
$text['hysteresis']     = 'Hysteresis';
$text['s_limit']        = 'Limit';
$text['s_label']        = 'Label';
$text['degree_mark']    = '&ordm;C';
$text['voltage_mark']   = 'V';
$text['rpm_mark']       = 'RPM';

$text['app']		= '- Kernel + applications';
$text['buffers']	= '- Buffers';
$text['cached']		= '- Cached';

?>

==> phpsysinfo_2.5.2.orig.tar.gz: phpsysinfo/includes/lang/sk.php <==
<?php
//
// phpSysInfo - A PHP System Information Script
// http://phpsysinfo.sourceforge.net/
//
// This program is free software; you can redistribute it and/or
// modify it under the terms of the GNU General Public License
// as published by the Free Software Foundation; either version 2
// of the License, or (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
//
// $Id: sk.php,v 1.15 2006/06/05 11:48:16 bigmichi1 Exp $

$charset                = 'iso-8859-2';

$text['title']          = 'Informcie o systme';

$text['vitals']         = 'Zkladn informcie';
$text['hostname']       = 'Meno potaa';
$text['ip']             = 'IP adresa';
$text['kversion']       = 'Verzia jadra';
$text['dversion']       = 'Distro Name';
$text['uptime']         = 'Uptime';
$text['users']          = 'Prihlsench uvateov';
$text['loadavg']        = 'Priemer loadu';

$text['hardware']       = 'Hardwarov informcie';
$text['numcpu']         = 'Procesory';
$text['cpumodel']       = 'Model';
$text['cpuspeed']       = 'Frekvencia';
$text['busspeed']       = 'BUS Speed';
$text['cache']          = 'Vekos cache';
$text['bogomips']       = 'Bogomipsov';

$text['pci']            = 'PCI zariadenia';
$text['ide']            = 'IDE zariadenia';
$text['scsi']           = 'SCSI zariadenia';
$text['usb']            = 'USB zariadenia';

$text['netusage']       = 'Pouvanie siete';
$text['device']         = 'Zariadenia';
$text['received']       = 'Prijatch';
$text['sent']           = 'Odoslanch';
$text['errors']         = 'Chyby/Vypustench';

$text['memusage']       = 'Obsadenie pamti';
$text['phymem']         = 'Fyzick pam';
$text['swap']           = 'Swap';

$text['fs']             = 'Namountovan sborov systmy';
$text['mount']          = 'Adresr';
$text['partition']      = 'Partcia';

$text['percent']        = 'Obsadench';
$text['type']           = 'Typ';
$text['free']           = 'Vonch';
$text['used']           = 'Pouitch';
$text['size']           = 'Vekos';
$text['totals']         = 'Celkom';

$text['kb']             = 'KB';
$text['mb']             = 'MB';
$text['gb']             = 'GB';

$text['none']           = 'iadne';

$text['capacity']       = 'Kapacita';

$text['template']       = 'ablna';
$text['language']       = 'Jazyk';
$text['submit']         = 'Odosla';
$text['created']        = 'Vytvoren pomocou';
$text['locale']         = 'en_US';
$text['gen_time']       = 'on %b %d, %Y at %I:%M %p';

$text['days']           = 'dn';
$text['hours']          = 'hodn';
$text['minutes']        = 'mint';
  
$text['temperature']    = 'Temperature';
$text['voltage']        = 'Voltage';
$text['fans']           = 'Fans';
$text['s_value']        = 'Value';
$text['s_min']          = 'Min';
$text['s_max']          = 'Max';
$text['s_div']          = 'Div';
$text['hysteresis']     = 'Hysteresis';
$text['s_limit']        = 'Limit';
$text['s_label']        = 'Label';
$text['degreeC']        = '&ordm;C';
$text['degreeF']        = '&ordm;F';
$text['voltage_mark']   = 'V';
$text['rpm_mark']       = 'RPM';

$text['app']		= 'Kernel + applications';
$text['buffers']	= 'Buffers';
$text['cached']		= 'Cached';

$text['connections']    = 'Established Network Connections';
?>
